@@ -14,7 +14,6 @@ Only child objects :class:`AnalogSignal` and :class:`IrregularlySampledSignal`
 can be created.
 """
 
-import copy
 import logging
 from copy import deepcopy
 
@@ -123,7 +122,7 @@ class BaseSignal(DataObject):
         new_signal._copy_data_complement(self)
         # _copy_data_complement can't always copy array annotations,
         # so this needs to be done locally
-        new_signal.array_annotations = copy.deepcopy(self.array_annotations)
+        new_signal.array_annotations = deepcopy(self.array_annotations)
         return new_signal
 
     def _get_required_attributes(self, signal, units):
