@@ -9,6 +9,8 @@ Author: Samuel Garcia
 
 """
 
+import numpy as np
+
 from .baserawio import (
     BaseRawIO,
     _signal_channel_dtype,
@@ -18,11 +20,6 @@ from .baserawio import (
     _common_sig_characteristics,
 )
 
-import numpy as np
-
-import os
-import sys
-
 
 class WinEdrRawIO(BaseRawIO):
     extensions = ["EDR", "edr"]
