@@ -1,5 +1,6 @@
 import unittest
 
+import os
 import numpy as np
 
 from neo.rawio.neuralynxrawio.neuralynxrawio import NeuralynxRawIO
@@ -105,14 +106,15 @@ class TestNeuralynxRawIO(
         # check that there are only 3 memmaps
         self.assertEqual(len(rawio._sigs_memmaps[seg_idx]), 3)
 
-    def test_single_file_mode(self):
+    def test_include_filenames(self):
         """
-        Tests reading of single files.
+        Tests include_filenames with only one file
         """
 
         # test single analog signal channel
         fname = self.get_local_path("neuralynx/Cheetah_v5.6.3/original_data/CSC1.ncs")
-        rawio = NeuralynxRawIO(filename=fname)
+        dirname, filename = os.path.split(fname)
+        rawio = NeuralynxRawIO(dirname=dirname, include_filenames=filename)
         rawio.parse_header()
 
         self.assertEqual(rawio._nb_segment, 2)
@@ -127,7 +129,8 @@ class TestNeuralynxRawIO(
 
         # test one single electrode channel
         fname = self.get_local_path("neuralynx/Cheetah_v5.5.1/original_data/STet3a.nse")
-        rawio = NeuralynxRawIO(filename=fname)
+        dirname, filename = os.path.split(fname)
+        rawio = NeuralynxRawIO(dirname=dirname, include_filenames=filename)
         rawio.parse_header()
 
         self.assertEqual(rawio._nb_segment, 1)
@@ -143,7 +146,7 @@ class TestNeuralynxRawIO(
     def test_exclude_filenames(self):
         # exclude single ncs file from session
         dname = self.get_local_path("neuralynx/Cheetah_v5.6.3/original_data/")
-        rawio = NeuralynxRawIO(dirname=dname, exclude_filename="CSC2.ncs")
+        rawio = NeuralynxRawIO(dirname=dname, exclude_filenames="CSC2.ncs")
         rawio.parse_header()
 
         self.assertEqual(rawio._nb_segment, 2)
@@ -157,7 +160,7 @@ class TestNeuralynxRawIO(
         self.assertEqual(len(rawio.header["event_channels"]), 2)
 
         # exclude multiple files from session
-        rawio = NeuralynxRawIO(dirname=dname, exclude_filename=["Events.nev", "CSC2.ncs"])
+        rawio = NeuralynxRawIO(dirname=dname, exclude_filenames=["Events.nev", "CSC2.ncs"])
         rawio.parse_header()
 
         self.assertEqual(rawio._nb_segment, 2)
@@ -378,6 +381,7 @@ if __name__ == "__main__":
     # test = TestNeuralynxRawIO()
     # test.test_scan_ncs_files()
     # test.test_exclude_filenames()
+    # test.test_include_filenames()
 
     # test = TestNcsSectionsFactory()
     # test.test_ncsblocks_partial()
